@@ -62,7 +62,7 @@ $CURL "${BASE_FORTIO}fetch/localhost:8080$FORTIO_UI_PREFIX?url=http://localhost:
 $CURL "${BASE_FORTIO}fetch/localhost:8080$FORTIO_UI_PREFIX?url=localhost:8079&load=Start&qps=-1&json=on&n=100&runner=grpc" | grep '"SERVING": 100'
 # Check we get the logo (need to remove the CR from raw headers)
 VERSION=$(docker exec $DOCKERNAME $FORTIO_BIN_PATH version -s)
-LOGO_TYPE=$($CURL "${BASE_FORTIO}${VERSION}/static/img/logo.svg" | grep -i Content-Type: | tr -d '\r'| awk '{print $2}')
+LOGO_TYPE=$($CURL "${BASE_FORTIO}${VERSION}/static/img/fortio-logo.svg" | grep -i Content-Type: | tr -d '\r'| awk '{print $2}')
 if [ "$LOGO_TYPE" != "image/svg+xml" ]; then
   echo "Unexpected content type for the logo: $LOGO_TYPE"
   exit 1
@@ -86,10 +86,10 @@ VERSION=$(docker exec $DOCKERNAME $FORTIO_BIN_PATH version -s)
 for p in "" browse sync; do
   # Check the page doesn't 404s
   $CURL ${BASE_FORTIO}${p}
-  # Check that page includes 3 logos
-  LOGOS=$($CURL ${BASE_FORTIO}${p} | grep -c "${VERSION}/static/img/logo.svg")
-  if [ "$LOGOS" -ne 3 ]; then
-    echo "expected 3 logos in the ${p} page"
+  # Check that page includes the logo
+  LOGOS=$($CURL ${BASE_FORTIO}${p} | grep -c "${VERSION}/static/img/fortio-logo.svg")
+  if [ "$LOGOS" -ne 1 ]; then
+    echo "expected a logo in the ${p} page"
     exit 1
   fi
 done
@@ -113,7 +113,7 @@ docker exec $DOCKERNAME $FORTIO_BIN_PATH grpcping localhost
 PPROF_URL="$BASE_URL/debug/pprof/heap?debug=1"
 $CURL $PPROF_URL | grep -i TotalAlloc # should find this in memory profile
 # creating dummy container to hold a volume for test certs due to remote docker bind mount limitation.
-docker create -v $TEST_CERT_VOL --name $DOCKERSECVOLNAME docker.io/fortio/fortio.build:v34 /bin/true # cleaned up by name
+docker create -v $TEST_CERT_VOL --name $DOCKERSECVOLNAME docker.io/fortio/fortio.build:v35 /bin/true # cleaned up by name
 # copying cert files into the certs volume of the dummy container
 for f in ca.crt server.crt server.key; do docker cp $PWD/cert-tmp/$f $DOCKERSECVOLNAME:$TEST_CERT_VOL/$f; done
 # start server in secure grpc mode. uses non-default ports to avoid conflicts with fortio_server container.
