@@ -89,10 +89,13 @@ var (
 )
 
 const (
-	fetchURI    = "fetch/"
-	fetch2URI   = "fetch2/"
-	faviconPath = "/favicon.ico"
-	modegrpc    = "grpc"
+	fetchURI      = "fetch/"
+	fetch2URI     = "fetch2/"
+	restRunURI    = "rest/run"
+	restStatusURI = "rest/status"
+	restStopURI   = "rest/stop"
+	faviconPath   = "/favicon.ico"
+	modegrpc      = "grpc"
 )
 
 // TODO: auto map from (Http)RunnerOptions to form generation and/or accept
@@ -118,7 +121,7 @@ func Handler(w http.ResponseWriter, r *http.Request) {
 	fhttp.LogRequest(r, "UI")
 	mode := menu
 	JSONOnly := false
-	DoSave := (r.FormValue("save") == "on")
+	doSave := (r.FormValue("save") == "on")
 	url := r.FormValue("url")
 	runid := int64(0)
 	runner := r.FormValue("runner")
@@ -198,6 +201,7 @@ func Handler(w http.ResponseWriter, r *http.Request) {
 		runs[runid] = &ro
 		uiRunMapMutex.Unlock()
 		log.Infof("New run id %d", runid)
+		ro.RunID = id
 	}
 	httpopts := &fhttp.HTTPOptions{}
 	httpopts.HTTPReqTimeOut = timeout // to be normalized in init 0 replaced by default value
@@ -256,23 +260,7 @@ func Handler(w http.ResponseWriter, r *http.Request) {
 	case menu:
 		// nothing more to do
 	case stop:
-		if runid <= 0 { // Stop all
-			i := 0
-			uiRunMapMutex.Lock()
-			for _, v := range runs {
-				v.Abort()
-				i++
-			}
-			uiRunMapMutex.Unlock()
-			log.Infof("Interrupted all %d runs", i)
-		} else { // Stop one
-			uiRunMapMutex.Lock()
-			v, found := runs[runid]
-			if found {
-				v.Abort()
-			}
-			uiRunMapMutex.Unlock()
-		}
+		StopByRunID(runid)
 	case run:
 		// mode == run case:
 		for _, header := range r.Form["H"] {
@@ -330,6 +318,9 @@ func Handler(w http.ResponseWriter, r *http.Request) {
 			}
 			res, err = fhttp.RunHTTPTest(&o)
 		}
+		uiRunMapMutex.Lock()
+		delete(runs, ro.RunID)
+		uiRunMapMutex.Unlock()
 		if err != nil {
 			log.Errf("Init error for %s mode with url %s and options %+v : %v", runner, url, ro, err)
 
@@ -344,7 +335,7 @@ func Handler(w http.ResponseWriter, r *http.Request) {
 		}
 		savedAs := ""
 		id := res.Result().ID()
-		if DoSave {
+		if doSave {
 			savedAs = SaveJSON(id, json)
 		}
 		if JSONOnly {
@@ -359,14 +350,12 @@ func Handler(w http.ResponseWriter, r *http.Request) {
 			_, _ = w.Write([]byte(fmt.Sprintf("Saved result to <a href='%s'>%s</a>"+
 				" (<a href='browse?url=%s.json' target='_new'>graph link</a>)\n", savedAs, savedAs, id)))
 		}
-
 		_, _ = w.Write([]byte(fmt.Sprintf("All done %d calls %.3f ms avg, %.1f qps\n</pre>\n<script>\n",
 			res.Result().DurationHistogram.Count,
 			1000.*res.Result().DurationHistogram.Avg,
 			res.Result().ActualQPS)))
 		ResultToJsData(w, json)
 		_, _ = w.Write([]byte("</script><p>Go to <a href='./'>Top</a>.</p></body></html>\n"))
-		delete(runs, runid)
 	}
 }
 
@@ -913,6 +902,14 @@ func Serve(baseurl, port, debugpath, uipath, datadir string, percentileList []fl
 	mux.HandleFunc(uiPath+fetch2URI, fhttp.FetcherHandler2)
 	fhttp.CheckConnectionClosedHeader = true // needed for proxy to avoid errors
 
+	// New REST apis.
+	restRunPath := uiPath + restRunURI
+	mux.HandleFunc(restRunPath, RESTRunHandler)
+	restStatusPath := uiPath + restStatusURI
+	mux.HandleFunc(restStatusPath, RESTStatusHandler)
+	restStopPath := uiPath + restStopURI
+	mux.HandleFunc(restStopPath, RESTStopHandler)
+
 	logoPath = version.Short() + "/static/img/fortio-logo.svg"
 	chartJSPath = version.Short() + "/static/js/Chart.min.js"
 
